==> App-bif-0.1.5_4.tar.gz: App-bif-0.1.5_4/share/SQLite/db-v1/049-func-update-task.sql <==
CREATE TABLE func_update_task(
    change_id INTEGER NOT NULL,
    id INTEGER NOT NULL,
    task_status_id INTEGER,
    title VARCHAR
);

CREATE TRIGGER
    func_update_task_bi_1
BEFORE INSERT ON
    func_update_task
FOR EACH ROW BEGIN

    SELECT debug(
        NEW.id,
        NEW.change_id,
        NEW.task_status_id,
        NEW.title
    );

    UPDATE
        changes
    SET
        yaml = yaml || (
            SELECT
                '-' || x'0A'
                || '  _delta: update_task' || x'0A'
                || '  task_status_uuid: ' || COALESCE(s.uuid,'~') || x'0A'
                ||
                    CASE WHEN
                        NEW.title IS NULL
                    THEN
                        '  title: ~' || x'0A'
                    WHEN
                        NEW.title = '-'
                    THEN
                        '  title: ''-''' || x'0A'
                    WHEN
                        instr(NEW.title, x'0A') OR
                        instr(NEW.title, '\\')
                    THEN
                        '  title: "' 
                        || REPLACE(
                              REPLACE(
                                REPLACE(NEW.title, '\\', '\\\\'),
                                x'0A', '\n'), '"', '\"')
                        || '"' || x'0A'
                    WHEN
                        instr(NEW.title, ' ') OR
                        NEW.title = '' -- not at all sufficient
                    THEN
                        '  title: ''' || NEW.title || '''' || x'0A'
                    ELSE
                        '  title: ' || NEW.title || x'0A'
                    END
                || '  uuid: ' || t.uuid || x'0A'
            FROM
                topics t
            LEFT JOIN
                topics s
            ON
                s.id = NEW.task_status_id
            WHERE
                t.id = NEW.id
        )
    WHERE
        id = NEW.change_id
    ;

    INSERT INTO deltas(
        id,
        change_id,
        action
    )
    VALUES(
        nextval('deltas'),
        NEW.change_id,
        'update_task'
    );

    INSERT INTO
        topic_deltas(
            id,
            change_id,
            topic_id
        )
    VALUES(
        currval('deltas'),
        NEW.change_id,
        NEW.id
    );

    INSERT INTO
        task_deltas(
            id,
            change_id,
            task_id,
            task_status_id,
            title
        )
    VALUES(
        currval('deltas'),
        NEW.change_id,
        NEW.id,
        NEW.task_status_id,
        NEW.title
    );

    SELECT RAISE(IGNORE);

END;

==> App-bif-0.1.5_5.tar.gz: App-bif-0.1.5_5/share/SQLite/db-v1/049-func-update-task.sql <==
CREATE TABLE func_update_task(
    change_id INTEGER NOT NULL,
    id INTEGER NOT NULL,
    task_status_id INTEGER,
    title VARCHAR
);

CREATE TRIGGER
    func_update_task_bi_1
BEFORE INSERT ON
    func_update_task
FOR EACH ROW BEGIN

    SELECT debug(
        NEW.id,
        NEW.change_id,
        NEW.task_status_id,
        NEW.title
    );

    UPDATE
        changes
    SET
        yaml = yaml || (
            SELECT
                '-' || x'0A'
                || '  _delta: update_task' || x'0A'
                || '  task_status_uuid: ' || COALESCE(s.uuid,'~') || x'0A'
                ||
                    CASE WHEN
                        NEW.title IS NULL
                    THEN
                        '  title: ~' || x'0A'
                    WHEN
                        NEW.title = '-'
                    THEN
                        '  title: ''-''' || x'0A'
                    WHEN
                        instr(NEW.title, x'0A') OR
                        instr(NEW.title, '\\')
                    THEN
                        '  title: "' 
                        || REPLACE(
                              REPLACE(
                                REPLACE(NEW.title, '\\', '\\\\'),
                                x'0A', '\n'), '"', '\"')
                        || '"' || x'0A'
                    WHEN
                        instr(NEW.title, ' ') OR
                        NEW.title = '' -- not at all sufficient
                    THEN
                        '  title: ''' || NEW.title || '''' || x'0A'
                    ELSE
                        '  title: ' || NEW.title || x'0A'
                    END
                || '  uuid: ' || n.uuid || x'0A'
            FROM
                nodes n
            LEFT JOIN
                nodes s
            ON
                s.id = NEW.task_status_id
            WHERE
                n.id = NEW.id
        )
    WHERE
        id = NEW.change_id
    ;

    INSERT INTO deltas(
        id,
        change_id,
        action
    )
    VALUES(
        nextval('deltas'),
        NEW.change_id,
        'update_task'
    );

    INSERT INTO
        node_deltas(
            id,
            change_id,
            node_id
        )
    VALUES(
        currval('deltas'),
        NEW.change_id,
        NEW.id
    );

    INSERT INTO
        task_deltas(
            id,
            change_id,
            task_id,
            task_status_id,
            title
        )
    VALUES(
        currval('deltas'),
        NEW.change_id,
        NEW.id,
        NEW.task_status_id,
        NEW.title
    );

    SELECT RAISE(IGNORE);

END;
